/* AlbumCover */
.albumcover-title-label {
    color: @theme_fg_color;
}

.albumcover-artist-label {
    font-size: smaller;
    color: @theme_fg_color;
}

/* AlbumsView */

#albums gridview {
  padding: 18px;
}

#albums gridview > child {
  margin: 9px;
  padding: 6px;
}

/* By default in Adwaita dark this is not transparent */
.tile {
    background-color: transparent;
}

.playlist-icon {
    padding: 10px;
    border-radius: 50%;
    background-color: alpha(@theme_fg_color, 0.1);
}

.disc-label {
    color: alpha(@theme_fg_color, 0.8);
    padding: 12px 0;
}

/* PlayerToolbar */

.smooth-scale {
    padding-top: 0px;
    padding-bottom: 0px;
}

.grey-image {
    color: alpha(@theme_fg_color, 0.3);
}

/* Used in AlbumWidget and ArtistAlbumsWidget */
.playing-song-label {
    font-weight: bold;
}

/* TwoLineTip */
.tooltip-title {
  font-weight: bold;
}

.playlistdialog-row:selected {
    color: @theme_fg_color;
    background-color: @theme_insensitive_bg_color;
}

.playlistdialog-row:selected label {
    color: @theme_text_color;
}

/* SearchView */
.search-header {
  font-weight: bold;
}

/* dnd icon for SongWidget */
.drag-handle {
  color: alpha(@theme_fg_color, 0.4);
}

.drag-handle:backdrop {
  color: alpha(@theme_unfocused_fg_color, 0.4);
}

/* SongWidget rows */
.songwidget {
  padding: 12px;
}

/* Starring */
button.star:hover {
  opacity: 1;
}

@keyframes rotate_star {
  from { -gtk-icon-transform: rotate(-72deg); }
  to {}
}
@keyframes rotate_unstar {
  from { -gtk-icon-transform: rotate(72deg); }
  to {}
}

button.star.interacted.starred image {
  animation: rotate_star 0.4s ease;
}
button.star.interacted:not(.starred) image {
  animation: rotate_unstar 0.4s ease;
}
